from typing import List
from app import models, schemas
from sqlalchemy.orm import Session
import time

from app.crud import update_to_db


def create_airflow_run(db: Session, item: schemas.AirflowRunCreate):
    db_item = models.AirflowRun(**item.dict())
    db.add(db_item)
    db.commit()
    db.refresh(db_item)
    return db_item


def update_airflow_run(db: Session, item_id: int, update_item: schemas.AirflowRunUpdate):
    return update_to_db(update_item=update_item, item_id=item_id, db=db, model_cls=models.AirflowRun)


def get_airflow_runs(db: Session):
    res: List[models.AirflowRun] = db.query(models.AirflowRun).all()
    return res

def get_airflow_runs_by_af_job_ids(db: Session, job_ids: List[int]):
    res: List[models.AirflowRun] = db.query(models.AirflowRun)\
        .filter(models.AirflowRun.job_id.in_(job_ids)).all()
    return res


def get_airflow_run_once(db: Session, run_id: str, job_id: int):
    res: models.AirflowRun = db.query(models.AirflowRun).filter(models.AirflowRun.run_id == run_id,
                                                                models.AirflowRun.job_id == job_id).first()
    return res
