from typing import List, Optional

from pydantic import BaseModel

class DataManagementBase(BaseModel):
    # 数据名称
    name: str
    # 数据类型
    data_type: str
    # 数据条数
    data_num: int
    # 存储位置
    storage_location: str
    # 占用存储
    storage_usage: str
    # 存储路径
    storage_path: str
    # 完整性
    integrity: str
    # 创建人名称
    user_name: str
    # 创建人编号
    user_id: str
    # 项目编号
    project_id: str

class DataManagementCreate(DataManagementBase):
    class Config:
        schema_extra = {
            "example": {
                "name": "test",
                "data_type": "数据表",
                "data_num": 25,
                "storage_location": "minio",
                "storage_usage": "23M",
                "storage_path": "/datax/usgdcnkasojcxasuscbv",
                "integrity": "-",
                "user_name": "test",
                "user_id": "test",
                "project_id": "test",
            }
        }

class DataManagement(DataManagementBase):
    id: int
    # 创建时间
    create_time: int
    class Config:
        orm_mode = True


class DataManagementSelect(BaseModel):
    user_id: str
    project_id: str
    class Config:
        schema_extra = {
            "example": {
                "user_id": "test",
                "project_id": "test",
            }
        }